package hfm_utils;

#---------------------------------------------------------------------------------
#---------------------------      hfm_utils.pm    --------------------------------
#---------------------------------------------------------------------------------
# Diverse Routinen 
# (c) DH1AAD / Ingo Gerlach  
# 
# Beschreibung:
#
# 0.2 01.03.2002/ige :  diverse Erweiterungen
# 0.1 28.07.2001/ige :	Ausgelagert aus Hauptmodul

#---------------------------------------------------------------------------------
#-----------------------        Module          ----------------------------------
#---------------------------------------------------------------------------------

 use strict;
 use Carp;
 use vars qw($VERSION @ISA @EXPORT_OK $AUTOLOAD);
 use Tk;
 use POSIX qw(strftime);

 require Exporter;
 require DynaLoader;
 require AutoLoader;

 @ISA = qw(Exporter DynaLoader);
 @EXPORT_OK = qw() ;
 $VERSION = '0.1';

#---------------------------------------------------------------------------------
#----------------------------     Funcs        -----------------------------------
#---------------------------------------------------------------------------------

sub get_config($ $);		# bergabe CFG-File , cfg-Hash, Ret cfg-Hash
sub write_config(@);		# bergabe CFG-File , cfg-Hash

sub init_port(@);		# Initialisiert i2c Port , Ret 1 Ok, 0 i2c nicht gefunden

sub check_log_size($ $);	# Logfile groesse prfen und STDERR ffnen
sub logmsg (@);			# Meldung in's Logfile schreiben

sub pop_up_question($ $); 
sub pop_up_info($ $);
sub pop_up_warning($ $);
sub CenterWindow($ $ $);

sub dbm2ypos(@);		# Berechnung dbm nach Y-Pos
sub rx2ypos(@);			# Y-Pos fr RX , ToDo
sub calc_dbm_scale(@);		# Gibt absoluten dbm-Bereich zurck -60,30 = 90;
sub ad2dbm(@);			# Berechnet AD8307 dBm

#---------------------------------------------------------------------------------
#---------------------------      Subs-Config    ---------------------------------
#---------------------------------------------------------------------------------
  
sub get_config($ $) {
my $config = $_[0];
my $cfgref = $_[1];
my %cfgd   = %$cfgref;

my @sd;
 open (CFG,$config) || logmsg("Kann CFG ($config) nicht oeffnen");
  LINE: while (<CFG>) {
   chomp;
   next LINE if (!/^[a-zA-Z0-9]/) ;
   @sd=split(/:/,$_);
   $cfgd{$sd[0]}	= $sd[1];
  }
  close(CFG);
  if (exists ($cfgd{"Debug"})) {
   if ($cfgd{"Debug"}!=0) {
    my $key;
    my $val;
    while (($key, $val) = each %cfgd) {
     print "hfm_utils:get_config: $key -> $val \n";
    }
   } 
  } 
 return %cfgd;
}

sub write_config(@){
my $config = shift;
my %cfgd   = @_;
 my $key;
 
 open (CFG,">${config}") or warn "can't open Config $config ?! \n";
 foreach $key (sort keys %cfgd) {
  print CFG "$key:$cfgd{$key}\n";
 }
 close(CFG);
}

#---------------------------------------------------------------------------------
#-----------------------------------      i2c    ---------------------------------
#---------------------------------------------------------------------------------

sub init_port(@) {
my %cfg   = @_;
my $iport;

 if ($cfg{"SERVER"} == 0) { i2c_client::server_quit(); } 	# Falls einer aktiv dann beenden
 $iport = i2c_client::server_check($cfg{"SERVER"},$cfg{"SERVER_BIN"},$cfg{"SOCKET_NAME"},$cfg{"PORT"},$cfg{"I2C_PORTDELAY"});

 if($iport == -1) {
  if($cfg{"SERVER"}!=0) { sleep(3); }    			# Falls Server, Moment warten das er starten kann
 } 
 $iport = i2c_client::init($cfg{"SERVER"});
 if ($iport > 0) {
  logmsg(sprintf("I2C-Interface found on Port 0x%0xh ",$iport));
 } else {
   logmsg("I2C-Interface not found.");
   return 0;
  }
 return 1;
}

#---------------------------------------------------------------------------------
#-----------------------------------      Logging    ---------------------------------
#---------------------------------------------------------------------------------

sub check_log_size($ $) {
my $logfile = $_[0];
my $logsize = $_[1];
 
 if ((stat($logfile))[7] > $logsize) {
  system("mv $logfile $logfile.old ");
 }
 open(STDERR,">>$logfile") || die "Logfile kann nicht geoeffnet werden. $logfile \n";
} 

sub logmsg (@)
{
 print STDERR strftime("%d.%m.%Y %H:%M:%S", localtime)," :  @_  \n";
 # print STDERR scalar localtime(time)," :  @_  \n";
} 

#---------------------------------------------------------------------------------
#---------------------------      Subs-pop-up    ---------------------------------
#---------------------------------------------------------------------------------
sub pop_up_question($ $) {
 my $main = $_[0];
 my $pop_message=$_[1];
 my $response = 0; 
 $response = $main->messageBox(-icon => 'question',
                               -text=>$pop_message,
                               -title => 'Info', 
                               -type => 'OkCancel',
                               -default =>'Ok'); 
 return $response;
} 


sub pop_up_info($ $) {
 my $main = $_[0];
 my $pop_message=$_[1];
 my $response = 0; 
 $response = $main->messageBox(-icon => 'info',
			       -width => 45,
 			       -text=>$pop_message,
 			       -title => 'Info',
 			       -type => 'Ok', 
 			       -default =>'Ok'); 
 return $response;
}


sub pop_up_warning($ $) {
 my $main =$_[0];
 my $pop_message=$_[1];
 my $response = 0; 
 $response = $main->messageBox(-icon => 'warning',
			       -width => 45,
 		               -text=>$pop_message,
 		               -title => 'Error',
 		                -type => 'Ok',
 		                -default =>'Ok'); 
 return $response;
}
#############################################################


#############################################################
# Zeigt das Fenstert zentriert an 
# aus Inet / Author Marc Dashevsky 
sub CenterWindow($ $ $) { 
#############################################################
# Args: (0) window to center 
#      (1) [optional] desired width 
#      (2) [optional] desired height 
# 
# Returns: *nothing* 
#################################################### 
 my($window, $width, $height) = @_; 
  
 # $window->idletasks; ??? 
 $width  = $window->reqwidth  unless $width; 
 $height = $window->reqheight unless $height; 
 my $x = int(($window->screenwidth  / 2) - ($width  / 2)); 
 my $y = int(($window->screenheight / 2) - ($height / 2)); 
 $window->geometry($width . "x" . $height . "+" . $x . "+" . $y);  
} 

#---------------------------------------------------------------------------------
#--------------------------------  Berechnung    ---------------------------------
#---------------------------------------------------------------------------------

sub dbm2ypos(@) { 
my ($dbm,$syStep,$dr1,$dBm_min) = @_;
 my $ypos =  $dr1 - ((($dbm - $dBm_min) / 10)* $syStep);
 return ($ypos); 
} 

sub calc_dbm_scale(@) {
my ($dBm_min,$dBm_max) = @_;
my $j;
 if ($dBm_max < 0 ) {
  $j = int(($dBm_min-$dBm_max) / 10)* -1;
 } else 
   {
    $j = int((($dBm_min / 10)* -1) + ($dBm_max / 10));
   }
 return $j; 
}

sub _ypos2dBm(@) { 
my ($ypos,$syStep,$dBm_min) = @_;
 my $db; 
 $db = ( 10 * ($ypos / $syStep)) +$dBm_min  ; 
return ($db); 
} 

# Vergleicht $rx mit marker und gibt 1 zurck wenn rx groesser ist
sub cmp_dBm_rx {
 my $rx   = $_[0]; # Wert rxval
 my $rxval;
# if($rx > $nullSet) { $rx += ((($att_db+$cfg{"ATT_FIX"}) / 10) * $dbStep); }
# $rxval = rx2dbm($rx,$nullSet,$dbStep,$dBm_min);
 # print "rx $rx , rxval $rxval , marker $marker_val \n";
 # return (($rxval > $marker_val) ? 1 : 0);
}

sub rx2ypos(@) {
 my ($rx,$dbStep,$syStep,$offs,$att_fix,$att_db) = @_;
 my $ypos = 0; 
 if($rx > $offs) { $rx += ((($att_db+$att_fix) / 10) * $dbStep); } # dbAtt immer bercksichtigen 16.07.01
 $ypos = (($rx - ($offs)) / $dbStep) * $syStep; 
 return ($ypos); 
}

sub ad2dbm(@) {
my ($val,$fac,$offs,$min) = @_;
my $temp=0;
 $temp = ($val*$fac)-$offs+$min;
 return($temp);
}

1;
__END__

=head1 NAME

hfm_utils - hfm_utils Ver. 0.2 / 02.03.2002

=head1 SYNOPSIS

        use hfm_utils;

=head1 DESCRIPTION 

	%cfg= &get_config('config.cfg',\%cfg);	# bergabe CFG-File , Rckgabe cfg-Hash
        write_config($config,%cfg);		# bergabe CFG-File , cfg-Hash

	OK = init_port(%cfg);			# Initialisiert i2c Port , Ret 1 Ok, 0 i2c nicht gefunden

	sub check_log_size($ $);		# Logfile groesse prfen und STDERR ffnen
	sub logmsg (@);				# Schreibt Meldung mit Datum/Uhrzeit nach STDERR

	$ypos=dbm2ypos(@);			# Berechnet dbm zu ScreenY 
	my ($dbm,$syStep,$dr1,$dBm_min) = @_;

	rx2ypos(@);				# Y-Pos fr RX , ToDo

	$dbm_range = calc_dbm_scale(@);		# Gibt dBm-Bereich zurck
	my ($dBm_min,$dBm_max) = @_;

	sub ad2dbm(@);

=head1 AUTHOR
IngoGerlach@welfen-netz.com (DH1AAD) 02.03.2002
 
=head1 SEE ALSO
 
perl(1).
 
=cut
