/***********************************************************************/
/*  TSA5511 Funktionen						       */	
/*  fuer i2c-Interface 	 				               */
/*  V0.1  erstellt am  : 07.05.2001 / I. Gerlach                       */
/*  Dateiname          : tsa5511.c				       */
/*                		       				       */
/*  Aenderungen : 						       */
/* 04.08.01 , Erweiterung tsa_struc, QuarzFrequenz                     */
/* 07.05.01 , Start Test 70cm Messender f. Tuner 		       */
/*                                                                     */
/***********************************************************************/

/*


Der TSA5511 arbeitet zwischen 64-1300MHz, Schrittweite ist 62,5 KHz. (Quarz 4,00MHz)
Der feste Vorteiler P ist 8. 
Der Variable Vorteiler N hat einen Bereich von 1 ??? -32767.
Als Frequenzteiler liegt der kleinste Bereich bei nmin = P * Nmin = 8 * 256 = 2048 

Ansteuerung TSA5511
 
		128	64	32	16	8	4	2	1	
--------------------------------------------------------------------------
Adresse:	1	1	0	0	0	A1	A0	R/W  : 192	
Teiler1:	0	N14	N13	N12	N11	N10	N9	N8 
Teiler2:	N7	N6	N5	N4	N3	N2	N1	N0
Control1:	1	CP	T1	T0	1	1	1	0S (0)   
Control2:	P7	P6	P5	P4	P3	P2	P1	P0

Betrieb:	R/W=0 		write / 1 = read
		CP=1		Charge Pump high 
		T0=T1=T2=0 	PLL
		T0=T1=T2=1	Test


*/

#define TSA5511_ADR	192		// SDA3302 Adresse default 192 , (194, 196, 198 )
#define TSA5511_STEP	62500		// Abstimmschritt 62.500 KHz 4.00MHz */
#define TSA5511_P	8		// Fester Vorteiler 8
#define TSA5511_Q	4000000		// Ref. Quarz 4.0000 MHz */
#define TSA5511_QDF	512		// Interner Teiler f. Quarz / 512  
#define TSA5511_PLL	206		// PLL , CP , Step 100 KHz
#define TSA5511_DIV	238		// Testmode ?

typedef struct tsa_struc {
 int div1;				// wird Berechnet n14-n8
 int div2;				// wird Berechnet n7 -n0
 int cnt1;				// 206 PLL 
 int cnt2;				// Bandswitch
 long quarz;				// bei 0 wird def. = 4 MHz verwendet
 int step;				// QF / (512/8) = QF / 64
} tsa_struc;

tsa_struc tsa5511; 				// tsa-Daten

int tsa5511_init(tsa_struc *sp,int Mode,long Quarz); // Mode 206 PLL, 238 Teiler, -> Rckgabe Mode
int tsa5511_calc(tsa_struc *sp,long Freq,int dstep);// Berechnet die Teilerfaktoren in *sp , Rckgabe Teiler , dstep = 0 62,5KHz, 1 = 125KHz
int tsa5511_send(tsa_struc *sp,int Adr);	// Sendet die Daten an die PLL, Adr 0,2,4,6 
int tsa5511_read(int Adr);		// Liest von der PLL, Adr 0,2,4,6 
					// Rckgabe Statusbyte BIT gesetzt PLL locked.
