/***********************************************************************/
/*  TSA5523 Funktionen						       */	
/*  fuer i2c-Interface 	 				               */
/*  V0.1  erstellt am  : 19.02.2001 / I. Gerlach                       */
/*  Dateiname          : tsa5523.c				       */
/*                		       				       */
/*  Aenderungen : 						       */
/*                                                                     */
/* 19.02.01 , Start Test mit TEMIC Tuner 3X7291 (WinTV go)	       */
/*                                                                     */
/***********************************************************************/

/*

Der TSA5523 arbeitet zwischen 64-1400MHz, Schrittweite ist 31,25/ 50,0 / 62,5 KHz. 
Der feste Vorteiler P ist 8. 
Der Variable Vorteiler N hat einen Bereich von 1 ??? -32767.
Als Frequenzteiler liegt der kleinste Bereich bei nmin = P * Nmin = 8 * 256 = 2048 
Die Quarzfrequenz liegt bei 4.00 MHz, der Teiler Q= 1024 / 640  / 512.

Ansteuereung TSA5523
 
		128	64	32	16	8	4	2	1	
--------------------------------------------------------------------------
Adresse:	1	1	0	0	0	A1	A0	R/W  : 192	
Teiler1:	0	N14	N13	N12	N11	N10	N9	N8 
Teiler2:	N7	N6	N5	N4	N3	N2	N1	N0
Control1:	1	CP	T2	T1	T0	RSA	RSB	0   
Control2:	P7	P6	P5	P4	P3	P2	P1	P0

Betrieb:	R/W=0 		write / 1 = read
		CP=1		Charge Pump high 
		T0=1;T1=T2=0 	PLL
		T0=T1=T2=1	Test

Ref Teiler

RSA	RSB	div.	Step	fref
1	1	512	62.5	7.8125
x	0	640	50.0	6.25
0	1	1024	31.25	3.90625		

Laut Datenblatt ergeben sich folgende Bereiche (Wird ueber P4-P5-P7, geschaltet).

Bereiche:	Low  VHF	 48-168	MHz
		High VHF	175-447	MHz
		UHF		455-855	MHz

*/

#define TSA5523_ADR	192		// SDA3302 Adresse default 192 , (194, 196, 198 )
#define TSA5523_STEP	50000		// Abstimmschritt 50.000 KHz
#define TSA5523_ZF	37300000 	// ZF 37,3 MHz , bzw. 0
#define TSA5523_P	8		// Fester Vorteiler 8
#define TSA5523_Q	4000000		// Ref. Quarz 4.00 MHz
#define TSA5523_QDF	640		// Interner Teiler f. Quarz / 640  
#define TSA5523_PLL	200		// PLL , CP , Step 50 KHz
#define TSA5523_DIV	238		// Testmode ?
#define TSA5523_BS0B	 48500000	// Umschaltbereich 
#define TSA5523_BS1B	169000000	// Umschaltbereich
#define TSA5523_BS2B	454000000	// Umschaltbereich
#define TSA5523_BS0	160		// Umschaltbereich P5 P7
#define TSA5523_BS1	144		// Umschaltbereich P4 P7
#define TSA5523_BS2	48		// Umschaltbereich P5 P4

typedef struct tsa5523 {
 int div1;				// wird Berechnet n14-n8
 int div2;				// wird Berechnet n7 -n0
 int cnt1;				// 206 PLL 
 int cnt2;				// Bandswitch
} tsa5523;

tsa5523 tsa5; 				// tsa-Daten

int tsa5523_init(tsa5523 *sp,int Mode); // Mode 206 PLL, 238 Teiler, -> Rckgabe Mode
int tsa5523_calc(tsa5523 *sp,long Freq,int dstep);// Berechnet die Teilerfaktoren in *sp , Rckgabe Teiler , dstep = 0 62,5KHz, 1 = 125KHz
int tsa5523_send(tsa5523 *sp,int Adr);	// Sendet die Daten an die PLL, Adr 0,2,4,6 
int tsa5523_read(int Adr);		// Liest von der PLL, Adr 0,2,4,6 
					// Rckgabe Statusbyte BIT gesetzt PLL locked.
